==> plasma-mediacenter-0.8.90.tar.bz2: plasma-mediacenter/browsingbackends/metadatabackends/metadatavideobackend/metadatavideobackend.h <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *   Copyright 2011 Sinny Kumari <ksinny@gmail.com>
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef METADATAVIDEOBACKEND_H
#define METADATAVIDEOBACKEND_H

#include <libs/mediacenter/abstractbrowsingbackend.h>

#include "../abstractmetadatabackend.h"

class MetadataVideoBackend : public AbstractMetadataBackend
{
    Q_OBJECT
public:
    MetadataVideoBackend (QObject* parent, const QVariantList& args);
    virtual ~MetadataVideoBackend();

public Q_SLOTS:
    virtual void init();
};

#endif // METADATAVIDEOBACKEND_H

==> plasma-mediacenter-1.1.0a.tar.bz2: plasma-mediacenter/browsingbackends/metadatabackends/metadatavideobackend/metadatavideobackend.h <==
/***************************************************************************
 *   Copyright 2009 by Alessandro Diaferia <alediaferia@gmail.com>         *
 *   Copyright 2011 Sinny Kumari <ksinny@gmail.com>
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef METADATAVIDEOBACKEND_H
#define METADATAVIDEOBACKEND_H

#include "../abstractmetadatabackend.h"

class MetadataVideoBackend : public AbstractMetadataBackend
{
    Q_OBJECT
public:
    MetadataVideoBackend (QObject* parent, const QVariantList& args);
    virtual ~MetadataVideoBackend();

    virtual bool supportsSearch() const;
    virtual void search(const QString& searchTerm);

protected:
    virtual bool initImpl();
};

#endif // METADATAVIDEOBACKEND_H
